/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package bufferings.ktr.i18n.test.client;

import bufferings.ktr.i18n.test.client.service.KtrI18NTestService;
import bufferings.ktr.i18n.test.client.service.KtrI18NTestServiceAsync;

import com.google.gwt.core.client.EntryPoint;
import com.google.gwt.core.client.GWT;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.FlexTable;
import com.google.gwt.user.client.ui.Label;
import com.google.gwt.user.client.ui.RootPanel;

/**
 * Entry point classes define <code>onModuleLoad()</code>.
 *
 * @author bufferings[at]gmail.com
 */
public class KtrI18NTest implements EntryPoint {

  /** Service proxy for test */
  private final KtrI18NTestServiceAsync ktrI18NTestService =
    GWT.create(KtrI18NTestService.class);

  /**
   * This is the entry point method.
   */
  public void onModuleLoad() {
    final Label label = new Label("loading...");
    RootPanel.get("KtrI18NTest").add(label);

    ktrI18NTestService.getSampleDTO(new AsyncCallback<SampleDTO>() {

      @Override
      public void onFailure(Throwable caught) {
        label.setText("Fail!");
      }

      @Override
      public void onSuccess(SampleDTO serverDTO) {
        SampleDTO clientDTO = createClientData();

        FlexTable t = new FlexTable();

        int row = 0;
        t.setText(row, 0, "Name");
        t.setText(row, 1, "Type");
        t.setText(row, 2, "Server Locale");
        t.setText(row, 3, "Client Value");
        t.setText(row, 4, "Server Value");

        row++;
        t.setText(row, 0, "SimpleName");
        t.setText(row, 1, "Constants");
        t.setText(row, 2, "-");
        t.setText(row, 3, clientDTO.simpleNameConst);
        t.setText(row, 4, serverDTO.simpleNameConst);

        row++;
        t.setText(row, 0, "SimpleName");
        t.setText(row, 1, "Constants");
        t.setText(row, 2, "en");
        t.setText(row, 3, clientDTO.simpleNameConstEn);
        t.setText(row, 4, serverDTO.simpleNameConstEn);

        row++;
        t.setText(row, 0, "SimpleName");
        t.setText(row, 1, "Messages");
        t.setText(row, 2, "-");
        t.setText(row, 3, clientDTO.simpleNameMsg);
        t.setText(row, 4, serverDTO.simpleNameMsg);

        row++;
        t.setText(row, 0, "SimpleName");
        t.setText(row, 1, "Messages");
        t.setText(row, 2, "ja");
        t.setText(row, 3, clientDTO.simpleNameMsgJa);
        t.setText(row, 4, serverDTO.simpleNameMsgJa);

        row++;
        t.setText(row, 0, "QualifiedName");
        t.setText(row, 1, "Constants");
        t.setText(row, 2, "-");
        t.setText(row, 3, clientDTO.qualifiedNameConst);
        t.setText(row, 4, serverDTO.qualifiedNameConst);

        row++;
        t.setText(row, 0, "QualifiedName");
        t.setText(row, 1, "Constants");
        t.setText(row, 2, "en");
        t.setText(row, 3, clientDTO.qualifiedNameConstEn);
        t.setText(row, 4, serverDTO.qualifiedNameConstEn);

        row++;
        t.setText(row, 0, "QualifiedName");
        t.setText(row, 1, "Messages");
        t.setText(row, 2, "-");
        t.setText(row, 3, clientDTO.qualifiedNameMsg);
        t.setText(row, 4, serverDTO.qualifiedNameMsg);

        row++;
        t.setText(row, 0, "QualifiedName");
        t.setText(row, 1, "Messages");
        t.setText(row, 2, "ja");
        t.setText(row, 3, clientDTO.qualifiedNameMsgJa);
        t.setText(row, 4, serverDTO.qualifiedNameMsgJa);

        row++;
        t.setText(row, 0, "StaticImport");
        t.setText(row, 1, "Constants");
        t.setText(row, 2, "-");
        t.setText(row, 3, clientDTO.staticImportConst);
        t.setText(row, 4, serverDTO.staticImportConst);

        row++;
        t.setText(row, 0, "StaticImport");
        t.setText(row, 1, "Constants");
        t.setText(row, 2, "en");
        t.setText(row, 3, clientDTO.staticImportConstEn);
        t.setText(row, 4, serverDTO.staticImportConstEn);

        row++;
        t.setText(row, 0, "StaticImport");
        t.setText(row, 1, "Messages");
        t.setText(row, 2, "-");
        t.setText(row, 3, clientDTO.staticImportMsg);
        t.setText(row, 4, serverDTO.staticImportMsg);

        row++;
        t.setText(row, 0, "StaticImport");
        t.setText(row, 1, "Messages");
        t.setText(row, 2, "ja");
        t.setText(row, 3, clientDTO.staticImportMsgJa);
        t.setText(row, 4, serverDTO.staticImportMsgJa);

        row++;
        t.setText(row, 0, "StaticImportOnDemand");
        t.setText(row, 1, "Constants");
        t.setText(row, 2, "-");
        t.setText(row, 3, clientDTO.staticImportOnDemandConst);
        t.setText(row, 4, serverDTO.staticImportOnDemandConst);

        row++;
        t.setText(row, 0, "StaticImportOnDemand");
        t.setText(row, 1, "Constants");
        t.setText(row, 2, "en");
        t.setText(row, 3, clientDTO.staticImportOnDemandConstEn);
        t.setText(row, 4, serverDTO.staticImportOnDemandConstEn);

        row++;
        t.setText(row, 0, "StaticImportOnDemand");
        t.setText(row, 1, "Messages");
        t.setText(row, 2, "-");
        t.setText(row, 3, clientDTO.staticImportOnDemandMsg);
        t.setText(row, 4, serverDTO.staticImportOnDemandMsg);

        row++;
        t.setText(row, 0, "StaticImportOnDemand");
        t.setText(row, 1, "Messages");
        t.setText(row, 2, "ja");
        t.setText(row, 3, clientDTO.staticImportOnDemandMsgJa);
        t.setText(row, 4, serverDTO.staticImportOnDemandMsgJa);

        // style
        t.setCellSpacing(1);
        t.setStyleName("ktrI18NTestTable");
        t.getRowFormatter().setStyleName(0, "ktrI18NTestTableHeader");
        for (int i = 1; i < t.getRowCount(); i++) {
          t.getRowFormatter().setStyleName(i, "ktrI18NTestTableRow");
        }
        t.getColumnFormatter().setWidth(0, "70px");
        t.getColumnFormatter().setWidth(1, "70px");
        t.getColumnFormatter().setWidth(2, "70px");

        // add
        RootPanel.get("KtrI18NTest").remove(label);
        RootPanel.get("KtrI18NTest").add(t);
      }

    });

  }

  private SampleDTO createClientData() {
    SimpleNameSample simpleNameSample = new SimpleNameSample();
    QualifiedNameSample qualifiedNameSample = new QualifiedNameSample();
    StaticImportSample staticImportSample = new StaticImportSample();
    StaticImportOnDemandSample staticImportOnDemandSample =
      new StaticImportOnDemandSample();

    SampleDTO dto = new SampleDTO();
    dto.simpleNameConst = simpleNameSample.getMyConstants().SAMPLE_CONST_NAME();
    dto.simpleNameConstEn =
      simpleNameSample.getMyConstantsWithLocale("en", "").SAMPLE_CONST_NAME();
    dto.simpleNameMsg = simpleNameSample.getMyMessages().welcome("Client");
    dto.simpleNameMsgJa =
      simpleNameSample.getMyMessagesWithLocaleJa().welcome("Client");

    dto.qualifiedNameConst =
      qualifiedNameSample.getMyConstants().SAMPLE_CONST_NAME();
    dto.qualifiedNameConstEn =
      qualifiedNameSample
        .getMyConstantsWithLocale("en", "")
        .SAMPLE_CONST_NAME();
    dto.qualifiedNameMsg =
      qualifiedNameSample.getMyMessages().welcome("Client");
    dto.qualifiedNameMsgJa =
      qualifiedNameSample.getMyMessagesWithLocaleJa().welcome("Client");

    dto.staticImportConst =
      staticImportSample.getMyConstants().SAMPLE_CONST_NAME();
    dto.staticImportConstEn =
      staticImportSample.getMyConstantsWithLocale("en", "").SAMPLE_CONST_NAME();
    dto.staticImportMsg = staticImportSample.getMyMessages().welcome("Client");
    dto.staticImportMsgJa =
      staticImportSample.getMyMessagesWithLocaleJa().welcome("Client");

    dto.staticImportOnDemandConst =
      staticImportOnDemandSample.getMyConstants().SAMPLE_CONST_NAME();
    dto.staticImportOnDemandConstEn =
      staticImportOnDemandSample
        .getMyConstantsWithLocale("en", "")
        .SAMPLE_CONST_NAME();
    dto.staticImportOnDemandMsg =
      staticImportOnDemandSample.getMyMessages().welcome("Client");
    dto.staticImportOnDemandMsgJa =
      staticImportOnDemandSample.getMyMessagesWithLocaleJa().welcome("Client");

    return dto;
  }
}